@@ -57,7 +57,7 @@ irc_info_create_string_with_pointer (char **string, void *pointer)
         *string = malloc (64);
         if (*string)
         {
-            snprintf (*string, 64, "0x%lx", (unsigned long)pointer);
+            snprintf (*string, 64, "%p", pointer);
         }
     }
 }
@@ -298,14 +298,15 @@ irc_info_info_irc_buffer_cb (const void *pointer, void *data,
 
     /* search for server or channel buffer */
     if (server && ptr_server && channel)
+    {
         ptr_channel = irc_channel_search (ptr_server, channel);
+        if (!ptr_channel)
+            ptr_server = NULL;
+    }
 
-    if (server)
-        free (server);
-    if (channel)
-        free (channel);
-    if (host)
-        free (host);
+    free (server);
+    free (channel);
+    free (host);
 
     if (ptr_channel)
     {
