@@ -75,7 +75,7 @@ irc_sasl_mechanism_plain (const char *sasl_username, const char *sasl_password)
         answer_base64 = malloc (length * 4);
         if (answer_base64)
         {
-            if (weechat_string_base_encode (64, string, length - 1,
+            if (weechat_string_base_encode ("64", string, length - 1,
                                             answer_base64) < 0)
             {
                 free (answer_base64);
@@ -148,7 +148,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
         /* send username and nonce with form: "n,,n=username,r=nonce" */
         gcry_create_nonce (nonce_client, sizeof (nonce_client));
         length = weechat_string_base_encode (
-            64,
+            "64",
             nonce_client, sizeof (nonce_client),
             nonce_client_base64);
         if (length != sizeof (nonce_client_base64) - 1)
@@ -165,8 +165,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
         {
             snprintf (string, length + 1, "n,,n=%s,r=%s",
                       username2, nonce_client_base64);
-            if (server->sasl_scram_client_first)
-                free (server->sasl_scram_client_first);
+            free (server->sasl_scram_client_first);
             server->sasl_scram_client_first = strdup (string + 3);
         }
     }
@@ -176,7 +175,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
         data = malloc (strlen (data_base64) + 1);
         if (!data)
             goto memory_error;
-        if (weechat_string_base_decode (64, data_base64, data) <= 0)
+        if (weechat_string_base_decode ("64", data_base64, data) <= 0)
             goto base64_decode_error;
 
         /* split attributes */
@@ -191,14 +190,12 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
         {
             if (strncmp (attrs[i], "r=", 2) == 0)
             {
-                if (nonce_server)
-                    free (nonce_server);
+                free (nonce_server);
                 nonce_server = strdup (attrs[i] + 2);
             }
             else if (strncmp (attrs[i], "s=", 2) == 0)
             {
-                if (salt_base64)
-                    free (salt_base64);
+                free (salt_base64);
                 salt_base64 = strdup (attrs[i] + 2);
             }
             else if (strncmp (attrs[i], "i=", 2) == 0)
@@ -210,14 +207,12 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
             }
             else if (strncmp (attrs[i], "v=", 2) == 0)
             {
-                if (verifier_base64)
-                    free (verifier_base64);
+                free (verifier_base64);
                 verifier_base64 = strdup (attrs[i] + 2);
             }
             else if (strncmp (attrs[i], "e=", 2) == 0)
             {
-                if (attr_error)
-                    free (attr_error);
+                free (attr_error);
                 attr_error = strdup (attrs[i] + 2);
             }
         }
@@ -239,7 +234,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
             verifier = malloc (strlen (verifier_base64) + 1);
             if (!verifier)
                 goto memory_error;
-            verifier_size = weechat_string_base_decode (64, verifier_base64,
+            verifier_size = weechat_string_base_decode ("64", verifier_base64,
                                                         verifier);
             if (verifier_size <= 0)
                 goto base64_decode_error;
@@ -292,7 +287,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
             salt = malloc (strlen (salt_base64) + 1);
             if (!salt)
                 goto memory_error;
-            salt_size = weechat_string_base_decode (64, salt_base64, salt);
+            salt_size = weechat_string_base_decode ("64", salt_base64, salt);
             if (salt_size <= 0)
                 goto base64_decode_error;
             /* RFC: SaltedPassword := Hi(Normalize(password), salt, i) */
@@ -304,8 +299,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
                                              salted_password,
                                              &salted_password_size))
                 goto crypto_error;
-            if (server->sasl_scram_salted_pwd)
-                free (server->sasl_scram_salted_pwd);
+            free (server->sasl_scram_salted_pwd);
             server->sasl_scram_salted_pwd = malloc (salted_password_size);
             if (!server->sasl_scram_salted_pwd)
                 goto memory_error;
@@ -350,8 +344,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
                            auth_no_proof);
             if ((rc < 0) || (rc >= length))
                 goto memory_error;
-            if (server->sasl_scram_auth_message)
-                free (server->sasl_scram_auth_message);
+            free (server->sasl_scram_auth_message);
             server->sasl_scram_auth_message = strdup (auth_message);
             /* RFC: ClientSignature := HMAC(StoredKey, AuthMessage) */
             if (!weechat_crypto_hmac (stored_key,
@@ -370,7 +363,7 @@ irc_sasl_mechanism_scram (struct t_irc_server *server,
                 client_proof[i] = ((unsigned char)client_key[i] ^
                                    (unsigned char)client_signature[i]);
             }
-            if (weechat_string_base_encode (64, client_proof, client_key_size,
+            if (weechat_string_base_encode ("64", client_proof, client_key_size,
                                             client_proof_base64) < 0)
                 goto base64_encode_error;
             /* final message: auth_no_proof + "," + proof */
@@ -422,7 +415,7 @@ end:
             answer_base64 = malloc ((length + 1) * 4);
             if (answer_base64)
             {
-                if (weechat_string_base_encode (64, string, length,
+                if (weechat_string_base_encode ("64", string, length,
                                                 answer_base64) < 0)
                 {
                     free (answer_base64);
@@ -434,32 +427,19 @@ end:
         }
     }
 
-    if (string)
-        free (string);
-    if (username)
-        free (username);
-    if (username2)
-        free (username2);
-    if (data)
-        free (data);
-    if (attrs)
-        weechat_string_free_split (attrs);
-    if (nonce_server)
-        free (nonce_server);
-    if (salt_base64)
-        free (salt_base64);
-    if (salt)
-        free (salt);
-    if (verifier_base64)
-        free (verifier_base64);
-    if (verifier)
-        free (verifier);
-    if (attr_error)
-        free (attr_error);
-    if (auth_no_proof)
-        free (auth_no_proof);
-    if (auth_message)
-        free (auth_message);
+    free (string);
+    free (username);
+    free (username2);
+    free (data);
+    weechat_string_free_split (attrs);
+    free (nonce_server);
+    free (salt_base64);
+    free (salt);
+    free (verifier_base64);
+    free (verifier);
+    free (attr_error);
+    free (auth_no_proof);
+    free (auth_message);
 
     return answer_base64;
 }
@@ -492,8 +472,7 @@ irc_sasl_get_key_content (const char *sasl_key, char **sasl_error)
     if (options)
         weechat_hashtable_set (options, "directory", "config");
     key_path = weechat_string_eval_path_home (sasl_key, NULL, NULL, options);
-    if (options)
-        weechat_hashtable_free (options);
+    weechat_hashtable_free (options);
 
     if (key_path)
         content = weechat_file_get_content (key_path);
@@ -506,8 +485,7 @@ irc_sasl_get_key_content (const char *sasl_key, char **sasl_error)
         *sasl_error = strdup (str_error);
     }
 
-    if (key_path)
-        free (key_path);
+    free (key_path);
 
     return content;
 }
@@ -565,7 +543,7 @@ irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
         data = malloc (strlen (data_base64) + 1);
         if (!data)
             return NULL;
-        length_data = weechat_string_base_decode (64, data_base64, data);
+        length_data = weechat_string_base_decode ("64", data_base64, data);
 
         /* read file with private key */
         str_privkey = irc_sasl_get_key_content (sasl_key, sasl_error);
@@ -613,7 +591,7 @@ irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
                 pubkey_base64 = malloc ((x.size + 1 + 1) * 4);
                 if (pubkey_base64)
                 {
-                    if (weechat_string_base_encode (64, pubkey, x.size + 1,
+                    if (weechat_string_base_encode ("64", pubkey, x.size + 1,
                                                     pubkey_base64) >= 0)
                     {
                         weechat_printf (
@@ -690,7 +668,7 @@ irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
         answer_base64 = malloc ((length + 1) * 4);
         if (answer_base64)
         {
-            if (weechat_string_base_encode (64, string, length,
+            if (weechat_string_base_encode ("64", string, length,
                                             answer_base64) < 0)
             {
                 free (answer_base64);
@@ -699,8 +677,7 @@ irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
         }
     }
 
-    if (string)
-        free (string);
+    free (string);
 
     return answer_base64;
 
